@@ -5,7 +5,7 @@ from __future__ import annotations
 
 from dataclasses import dataclass
 from time import sleep as time_sleep
-from typing import Callable, Dict, List, Optional
+from typing import Dict, List, Optional
 
 import vlc
 
@@ -33,27 +33,10 @@ def inner_str(s: str, d: dict) -> str:
     return s
 
 
-def confirm_dummy() -> None:
-    ...
-
-
-def confirm_input() -> None:
-    input(">>> ")
-
-
-def conv_confirm_f(s: str) -> Callable:
-    s = s.lower()
-    if s == 'input':
-        return confirm_input
-    else:
-        return confirm_dummy
-
-
 @dataclass
 class Sound:
     message: str
     sound_filename: str
-    confirm_f: Callable
 
     def __post_init__(self) -> None:
         self.sound_filename = get_real_sound_filename(self.sound_filename)
@@ -68,7 +51,7 @@ class Sound:
         return Sound(
             message=json["message"],
             sound_filename=json["sound_filename"],
-            confirm_f=conv_confirm_f(json.get("confirm", "")))
+        )
 
     def __eq__(self, other) -> bool:
         return self.message == other.message and self.sound_filename == other.sound_filename
@@ -108,7 +91,6 @@ class ClockTimer:
                 is_first=sec == 0 and count == 1)
 
             ps.append(sound.run())
-            sound.confirm_f()
 
         while not any_ended_sounds(ps):
             time_sleep(1)
